<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Forneceu un valor incorrecto para %s",
"Saved" => "Gardado",
"test email settings" => "correo de proba dos axustes",
"If you received this email, the settings seem to be correct." => "Se recibiu este correo, semella que a configuración é correcta.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Produciuse un problema ao enviar o correo. Revise os seus axustes.",
"Email sent" => "Correo enviado",
"You need to set your user email before being able to send test emails." => "É necesario configurar o correo do usuario antes de poder enviar mensaxes de correo de proba.",
"Send mode" => "Modo de envío",
"Encryption" => "Cifrado",
"Authentication method" => "Método de autenticación",
"Unable to load list from App Store" => "Non foi posíbel cargar a lista desde a App Store",
"Authentication error" => "Produciuse un erro de autenticación",
"Your full name has been changed." => "O seu nome completo foi cambiado",
"Unable to change full name" => "Non é posíbel cambiar o nome completo",
"Group already exists" => "O grupo xa existe",
"Unable to add group" => "Non é posíbel engadir o grupo",
"Files decrypted successfully" => "Ficheiros descifrados satisfactoriamente",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Non foi posíbel descifrar os seus ficheiros. revise o ficheiro de rexistro owncloud.log, ou pregúntelle ao administrador",
"Couldn't decrypt your files, check your password and try again" => "Non foi posíbel descifrar os seus ficheiros. revise o seu contrasinal e ténteo de novo",
"Encryption keys deleted permanently" => "As chaves de cifrado foron eliminadas permanentemente",
"Couldn't permanently delete your encryption keys, please check your owncloud.log or ask your administrator" => "Non foi posíbel eliminar permanentemente as chaves de cifrado. revise o ficheiro de rexistro owncloud.log, ou pregúntelle ao administrador",
"Couldn't remove app." => "Non foi posíbel retirar o aplicativo.",
"Email saved" => "Correo gardado",
"Invalid email" => "Correo incorrecto",
"Unable to delete group" => "Non é posíbel eliminar o grupo.",
"Unable to delete user" => "Non é posíbel eliminar o usuario",
"Backups restored successfully" => "As copias de seguranza foron restauradas satisfactoriamente",
"Couldn't restore your encryption keys, please check your owncloud.log or ask your administrator" => "Non foi posíbel restaurar as chaves de cifrado. revise o ficheiro de rexistro owncloud.log, ou pregúntelle ao administrador",
"Language changed" => "O idioma cambiou",
"Invalid request" => "Petición incorrecta",
"Admins can't remove themself from the admin group" => "Os administradores non poden eliminarse a si mesmos do grupo admin",
"Unable to add user to group %s" => "Non é posíbel engadir o usuario ao grupo %s",
"Unable to remove user from group %s" => "Non é posíbel eliminar o usuario do grupo %s",
"Couldn't update app." => "Non foi posíbel actualizar o aplicativo.",
"Wrong password" => "Contrasinal incorrecto",
"No user supplied" => "Non subministrado polo usuario",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Forneza un contrasinal de recuperación do administrador de recuperación, senón perderanse todos os datos do usuario",
"Wrong admin recovery password. Please check the password and try again." => "Contrasinal de recuperación do administrador incorrecto. Comprobe o contrasinal e tenteo de novo.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "A infraestrutura non admite o cambio de contrasinal, mais a chave de cifrado dos usuarios foi actualizada correctamente.",
"Unable to change password" => "Non é posíbel cambiar o contrasinal",
"Sending..." => "Enviando...",
"User Documentation" => "Documentación do usuario",
"Admin Documentation" => "Documentación do administrador",
"Update to {appversion}" => "Actualizar á {appversion}",
"Uninstall App" => "Desinstalar un aplicativo",
"Disable" => "Desactivar",
"Enable" => "Activar",
"Please wait...." => "Agarde...",
"Error while disabling app" => "Produciuse un erro ao desactivar o aplicativo",
"Error while enabling app" => "Produciuse un erro ao activar o aplicativo",
"Updating...." => "Actualizando...",
"Error while updating app" => "Produciuse un erro mentres actualizaba o aplicativo",
"Error" => "Erro",
"Update" => "Actualizar",
"Updated" => "Actualizado",
"Uninstalling ...." => "Desinstalando ...",
"Error while uninstalling app" => "Produciuse un erro ao desinstalar o aplicatvo",
"Uninstall" => "Desinstalar",
"Select a profile picture" => "Seleccione unha imaxe para o perfil",
"Very weak password" => "Contrasinal moi feble",
"Weak password" => "Contrasinal feble",
"So-so password" => "Contrasinal non moi aló",
"Good password" => "Bo contrasinal",
"Strong password" => "Contrasinal forte",
"Decrypting files... Please wait, this can take some time." => "Descifrando ficheiros... isto pode levar un anaco.",
"Delete encryption keys permanently." => "Eliminar permanentemente as chaves de cifrado.",
"Restore encryption keys." => "Restaurar as chaves de cifrado.",
"Unable to delete {objName}" => "Non é posíbel eliminar {objName}",
"Error creating group" => "Produciuse un erro ao crear o grupo",
"A valid group name must be provided" => "Debe fornecer un nome de grupo",
"deleted {groupName}" => "{groupName} foi eliminado",
"undo" => "desfacer",
"Groups" => "Grupos",
"Group Admin" => "Grupo Admin",
"Delete" => "Eliminar",
"never" => "nunca",
"deleted {userName}" => "{userName} foi eliminado",
"add group" => "engadir un grupo",
"A valid username must be provided" => "Debe fornecer un nome de usuario",
"Error creating user" => "Produciuse un erro ao crear o usuario",
"A valid password must be provided" => "Debe fornecer un contrasinal",
"Warning: Home directory for user \"{user}\" already exists" => "Aviso: O directorio persoal para o usuario «{user}» xa existe",
"__language_name__" => "Galego",
"Everything (fatal issues, errors, warnings, info, debug)" => "Todo (problemas críticos, erros, avisos, información, depuración)",
"Info, warnings, errors and fatal issues" => "Información, avisos, erros e problemas críticos",
"Warnings, errors and fatal issues" => "Avisos, erros e problemas críticos",
"Errors and fatal issues" => "Erros e problemas críticos",
"Fatal issues only" => "Só problemas críticos",
"None" => "Ningún",
"Login" => "Acceso",
"Plain" => "Simple",
"NT LAN Manager" => "Xestor NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Aviso de seguranza",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Está accedendo a %s a través de HTTP. Suxerímoslle que configure o seu servidor para requirir, no seu canto, o uso de HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "O seu cartafol de datos e os seus ficheiros probabelmente sexan accesíbeis a través de internet. O ficheiro .htaccess non está a traballar. Suxerímoslle que configure o seu servidor web de tal maneira que o cartafol de datos non estea accesíbel ou que mova o o directorio de datos fóra da raíz de documentos do servidor web.",
"Setup Warning" => "Configurar os avisos",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "O seu servidor web non está aínda configurado adecuadamente para permitir a sincronización de ficheiros xa que semella que a interface WebDAV non está a funcionar.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Volva comprobar as <a href=\"%s\">guías de instalación</a>",
"PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." => "Parece que PHP foi configuración para substituír bloques de documentos en liña. Isto fará que varios aplicativos sexan inaccesíbeis.",
"This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." => "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
"Database Performance Info" => "Información do rendemento da base de datos",
"SQLite is used as database. For larger installations we recommend to change this. To migrate to another database use the command line tool: 'occ db:convert-type'" => "Empregarase SQLite como base de datos. Para instalacións máis grandes recomendámoslle que cambie isto. Para migrar a outra base de datos use a ferramenta en liña de ordes: «occ db:convert-type»",
"Module 'fileinfo' missing" => "Non se atopou o módulo «fileinfo»",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Non se atopou o módulo de PHP «fileinfo». É recomendábel activar este módulo para obter os mellores resultados coa detección do tipo MIME.",
"Your PHP version is outdated" => "A versión de PHP está desactualizada",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "A versión de PHP está desactualizada. Recomendámoslle que a actualice á versión 5.3.8 ou posterior xa que as versións anteriores son coñecidas por estragarse. É probábel que esta instalación no estea a funcionar correctamente.",
"Locale not working" => "A configuración rexional non funciona",
"System locale can not be set to a one which supports UTF-8." => "Non é posíbel estabelecer a configuración rexional do sistema a unha que admita UTF-8.",
"This means that there might be problems with certain characters in file names." => "Isto significa que pode haber problemas con certos caracteres en nomes de ficheiro.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Recomendamoslle que instale no sistema os paquetes necesarios para admitir unha das seguintes configuracións rexionais: %s.",
"Internet connection not working" => "A conexión á Internet non funciona",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Este servidor non ten conexión a Internet. Isto significa que algunhas das funcionalidades como a montaxe de almacenamento externo, as notificacións sobre actualizacións ou instalación de aplicativos de terceiros non funcionan. O acceso aos ficheiros de forma remota e o envío de mensaxes de notificación poderían non funcionar. Suxerímoslle que active a conexión a Internet deste servidor se quere dispor de todas as funcionalidades.",
"Cron" => "Cron",
"Last cron was executed at %s." => "O último «cron» executouse ás %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "O último «cron» executouse ás %s. Isto supón que pasou máis dunha hora. polo que semella que algo vai mal.",
"Cron was not executed yet!" => "«Cron» aínda non foi executado!",
"Execute one task with each page loaded" => "Executar unha tarefa con cada páxina cargada",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php está rexistrado nun servizo de WebCron para chamar a cron.php cada 15 minutos a través de HTTP.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Use o servizo de sistema cron para chamar ao ficheiro cron.php cada 15 minutos.",
"Sharing" => "Compartindo",
"Allow apps to use the Share API" => "Permitir que os aplicativos empreguen o API para compartir",
"Allow users to share via link" => "Permitir que os usuarios compartan a través de ligazóns",
"Enforce password protection" => "Forzar a protección por contrasinal",
"Allow public uploads" => "Permitir os envíos públicos",
"Set default expiration date" => "Definir a data predeterminada de caducidade",
"Expire after " => "Caduca após",
"days" => "días",
"Enforce expiration date" => "Obrigar a data de caducidade",
"Allow resharing" => "Permitir compartir",
"Restrict users to only share with users in their groups" => "Restrinxir aos usuarios a compartir só cos usuarios dos seus grupos",
"Allow users to send mail notification for shared files" => "Permitirlle aos usuarios enviar notificacións por correo para os ficheiros compartidos",
"Exclude groups from sharing" => "Excluír grupos da compartición",
"These groups will still be able to receive shares, but not to initiate them." => "Estes grupos poderán recibir comparticións, mais non inicialas.",
"Security" => "Seguranza",
"Enforce HTTPS" => "Forzar HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Forzar que os clientes se conecten a %s empregando unha conexión cifrada.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Conéctese a %s empregando HTTPS para activar ou desactivar o forzado de SSL.",
"Email Server" => "Servidor de correo",
"This is used for sending out notifications." => "Isto utilizase para o envío de notificacións.",
"From address" => "Desde o enderezo",
"mail" => "correo",
"Authentication required" => "Requírese autenticación",
"Server address" => "Enderezo do servidor",
"Port" => "Porto",
"Credentials" => "Credenciais",
"SMTP Username" => "Nome de usuario SMTP",
"SMTP Password" => "Contrasinal SMTP",
"Test email settings" => "Correo de proba dos axustes",
"Send email" => "Enviar o correo",
"Log" => "Rexistro",
"Log level" => "Nivel de rexistro",
"More" => "Máis",
"Less" => "Menos",
"Version" => "Versión",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Desenvolvido pola <a href=\"http://ownCloud.org/contact\" target=\"_blank\">comunidade ownCloud</a>, o <a href=\"https://github.com/owncloud\" target=\"_blank\">código fonte</a> está baixo a licenza <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Engada o seu aplicativo",
"More Apps" => "Máis aplicativos",
"Select an App" => "Escolla un aplicativo",
"Documentation:" => "Documentación:",
"See application page at apps.owncloud.com" => "Consulte a páxina do aplicativo en apps.owncloud.com",
"See application website" => "Vexa o sitio web do aplicativo",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-licenciado por<span class=\"author\"></span>",
"Enable only for specific groups" => "Activar só para grupos específicos",
"All" => "Todo",
"Administrator Documentation" => "Documentación do administrador",
"Online Documentation" => "Documentación na Rede",
"Forum" => "Foro",
"Bugtracker" => "Seguemento de fallos",
"Commercial Support" => "Asistencia comercial",
"Get the apps to sync your files" => "Obteña os aplicativos para sincronizar os seus ficheiros",
"Show First Run Wizard again" => "Amosar o axudante da primeira execución outra vez",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Ten en uso <strong>%s</strong> do total dispoñíbel de <strong>%s</strong>",
"Password" => "Contrasinal",
"Your password was changed" => "O seu contrasinal foi cambiado",
"Unable to change your password" => "Non é posíbel cambiar o seu contrasinal",
"Current password" => "Contrasinal actual",
"New password" => "Novo contrasinal",
"Change password" => "Cambiar o contrasinal",
"Full Name" => "Nome completo",
"Email" => "Correo",
"Your email address" => "O seu enderezo de correo",
"Fill in an email address to enable password recovery and receive notifications" => "Escriba un enderezo de correo para permitir a recuperación de contrasinais e recibir notificacións",
"Profile picture" => "Imaxe do perfil",
"Upload new" => "Novo envío",
"Select new from Files" => "Seleccione unha nova de ficheiros",
"Remove image" => "Retirar a imaxe",
"Either png or jpg. Ideally square but you will be able to crop it." => "Calquera png ou jpg. É preferíbel que sexa cadrada, mais poderá recortala.",
"Your avatar is provided by your original account." => "O seu avatar é fornecido pola súa conta orixinal.",
"Cancel" => "Cancelar",
"Choose as profile image" => "Escolla unha imaxe para o perfil",
"Language" => "Idioma",
"Help translate" => "Axude na tradución",
"The encryption app is no longer enabled, please decrypt all your files" => "O aplicativo de cifrado non está activado, descifre todos os ficheiros",
"Log-in password" => "Contrasinal de acceso",
"Decrypt all Files" => "Descifrar todos os ficheiros",
"Your encryption keys are moved to a backup location. If something went wrong you can restore the keys. Only delete them permanently if you are sure that all files are decrypted correctly." => "As chaves de cifrado foron movidas á copia de seguranza. Se ten algún problema pode restaurar as chaves. Elimineas permanentemente só se está seguro de que é posíbel descifrar correctamente todos os ficheiros.",
"Restore Encryption Keys" => "Restaurar as chaves de cifrado",
"Delete Encryption Keys" => "Eliminar as chaves de cifrado",
"Login Name" => "Nome de acceso",
"Create" => "Crear",
"Admin Recovery Password" => "Contrasinal de recuperación do administrador",
"Enter the recovery password in order to recover the users files during password change" => "Introduza o contrasinal de recuperación para recuperar os ficheiros dos usuarios durante o cambio de contrasinal",
"Search Users and Groups" => "Buscar usuarios e grupos",
"Add Group" => "Engadir un grupo",
"Group" => "Grupo",
"Everyone" => "Todos",
"Admins" => "Administradores",
"Default Quota" => "Cota por omisión",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Introduza a cota de almacenamento (p.ex. «512 MB» ou «12 GB»)",
"Unlimited" => "Sen límites",
"Other" => "Outro",
"Username" => "Nome de usuario",
"Quota" => "Cota",
"Storage Location" => "Localización do almacenamento",
"Last Login" => "Último acceso",
"change full name" => "Cambiar o nome completo",
"set new password" => "estabelecer un novo contrasinal",
"Default" => "Predeterminado",
"If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwritewebroot\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" => "Se a instalación non foi feita na raíz do dominio e usa o sistema de cron, poden xurdir problemas coa xeración dos URL. Para evitar estes problemas, axuste a opción «overwritewebroot» no ficheiro config.php ás ruta de webroot da súa instalación (suxírese: «%s»)",
"URL generation in notification emails" => "Xeración dos URL nos correos de notificación",
"Connectivity Checks" => "Comprobacións de conectividade",
"No problems found" => "Non se atoparon problemas",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
